#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Crée le Mon Feb 14 10:34:29 2022
@auteur: david ALBERTO
(www.astrolabe-science.fr)
Ce code utilise le module mendeleev (données sur les éléments chimiques)
"""
 # Paramètres personnalisables-----
Zmax=36
xmin=1#valeur minimale du pourcentage d'abondance naturelle
couleur_points='royalblue'
c_radio='orangered'#couleur du point pour les radio-isotopes
prop1=dict(s=20,c=couleur_points,ec='k',lw=0.5,zorder=2)#propriétés des points
prop2=dict(s=20,c=c_radio,ec='k',lw=0.5,zorder=3)#propriétés des points (noyaux radioactifs)
# ---------------------------------
# Appel des modules
import matplotlib.pyplot as plt
from mendeleev import element
from mendeleev.fetch import fetch_table
# ---------------------------------
ptable = fetch_table('elements')
isotopes = fetch_table('isotopes', index_col='id')
colonnes=['atomic_number','mass_number','abundance','is_radioactive']
donnees=isotopes[colonnes]
donnees=donnees[donnees['atomic_number']<=Zmax]#seulement les premiers éléments
N_atomique=donnees['atomic_number']#les N° atomiques de tous les isotopes listés
abondance=donnees['abundance']*100
radioactif=donnees['is_radioactive']
N_masse=donnees['mass_number']
symboles=[element(N).symbol for N in range(1,Zmax+1)]#création de la liste des symboles
# ---------------------------------
# Paramètres du graphique--------------------------
fig=plt.figure(figsize=(21/2.54,29.7/2.54),tight_layout=True,facecolor='#daf7e2')
ax=plt.subplot(111)
plt.rcParams["font.family"] = "Roboto"# ou autre police installée
plt.title("Abondance naturelle de quelques isotopes",fontsize=16)

 # Axe x------------------
ax.set_xscale('log')
ax.set_xlim(xmin,105)
extraticks=[1.5,15]+list(range(2,10))+list(range(20,100,10))
plt.xticks([1,10]+extraticks,[1,10]+extraticks)
plt.xlabel('Abondance naturelle (%)')

 # Axe y------------------
ax.invert_yaxis()#axeY croissant vers le bas
ax.set_ylim(Zmax+1,0)
plt.yticks(range(1,Zmax+1),symboles)#étiquettes des numéros atomiques
ax2=ax.twinx()# axe y supplémentaire à droite (numéro atomique)
ax2.invert_yaxis()
ax2.set_ylim(Zmax+1,0)
plt.yticks(list(range(1,Zmax+1)))
ax2.set_ylabel("Z",loc='top',rotation=0)

#tracé des points:-----------------------------
plt.scatter(abondance,N_atomique,**prop1)#tracé des points

ax.grid(zorder=-1,which='minor',alpha=0.5)
ax.grid(zorder=-1,which='major')

for N in donnees.index:
    if abondance[N]>=xmin:
        #écriture des nombres de masse :
        plt.text(abondance[N],N_atomique[N]-0.2,N_masse[N],fontsize=5,ha='center',alpha=0.8)
        # isotopes radioactifs :
        if radioactif[N]:
            plt.scatter(abondance[N],N_atomique[N],**prop2)
            plt.text(abondance[N],N_atomique[N]-0.2,N_masse[N],fontsize=5,ha='center',c=c_radio)

plt.scatter(0.01,0.99,**prop2,transform=ax.transAxes)
plt.text(0.018,0.99,"radioactif",va='center',transform=ax.transAxes)

fig.text(0.01,0.01,"D. Alberto (www.astrolabe-science.fr)",fontsize=8)
fig.savefig("AbondanceNaturelleIsotopes.pdf")
fig.savefig("AbondanceNaturelleIsotopes.png",dpi=300)

# plt.show()